diff mercurial/commands.py @ 8027:9c7ca86fc658

expand "repo" to "repository" in help texts
author Martin Geisler <mg@lazybytes.net>
date Tue, 07 Apr 2009 22:58:05 +0200
parents 683d8ebcf434
children 3aaca5901ade
line wrap: on
line diff
--- a/mercurial/commands.py	Tue Apr 07 22:47:56 2009 +0200
+++ b/mercurial/commands.py	Tue Apr 07 22:58:05 2009 +0200
@@ -542,7 +542,7 @@
     for the export command, with the following additions:
 
     %s   basename of file being printed
     %d   dirname of file being printed, or '.' if in repo root
     %p   root-relative path name of file being printed
     """
     ctx = repo[opts.get('rev')]
@@ -1538,7 +1538,7 @@
     """identify the working copy or specified revision
 
     With no revision, print a summary of the current state of the
-    repo.
+    repository.
 
     With a path, do a lookup in another repository.
 
@@ -2925,7 +2925,7 @@
     clone -U').
 
     When the working directory contains no uncommitted changes, it will be
-    replaced by the state of the requested revision from the repo.
+    replaced by the state of the requested revision from the repository.
     When the requested revision is on a different branch, the working
     directory will additionally be switched to that branch.
 
@@ -3387,7 +3387,7 @@
           ('n', 'name', '',
            _('name to show in web pages (default: working directory)')),
           ('', 'webdir-conf', '', _('name of the webdir config file'
-                                    ' (serve more than one repo)')),
+                                    ' (serve more than one repository)')),
           ('', 'pid-file', '', _('name of file to write process ID to')),
           ('', 'stdio', None, _('for remote clients')),
           ('t', 'templates', '', _('web templates to use')),
@@ -542,7 +542,7 @@
 
     %s   basename of file being printed
-    %d   dirname of file being printed, or '.' if in repo root
+    %d   dirname of file being printed, or '.' if in repository root
     %p   root-relative path name of file being printed
     """